import MapBase from "./MapBase";
import * as Utils from "./utils";

class LotMap extends MapBase {
  constructor(props) {
    super(props);

    this.geoJsonBorder = Utils.featureCollectionConfig();
    this.geoJsonFill = Utils.featureCollectionConfig();
  }

  componentDidUpdate(prevProps) {
    const { lot } = this.props;
    if (lot !== prevProps.lot) {
      this.map.setCenter([lot.position._longitude, lot.position._latitude]);
      this.map.setZoom(16.5);
    }
  }

  draw() {
    const { lot } = this.props;
    const lng = lot.position._longitude;
    const lat = lot.position._latitude;
    // const { lng, lat } = this.map.getCenter();
    const zoom = this.map.getZoom().toFixed(2);

    this.setState({ lng, lat, zoom, loading: true });

    if (!lot) return;

    this.map.setCenter({ lng, lat });

    const coords = Utils.lotDrawCoords({ coords: lot.coordinates, zoom });

    const poly1 = Utils.featureConfig([...coords, coords[0]]);

    const poly2 = Utils.featureConfig([...coords]);

    this.geoJsonBorder.features = [poly1];
    this.geoJsonFill.features = [poly2];

    const sourceBorder = this.map.getSource("lot-border");
    sourceBorder && sourceBorder.setData(this.geoJsonBorder);
    const sourceFill = this.map.getSource("lot-fill");
    sourceFill && sourceFill.setData(this.geoJsonFill);
    this.setState({ loading: false });
  }

  onMapLoad() {
    const { map, geoJsonBorder, geoJsonFill } = this;
    Utils.addOutlineLayer({ map, id: "lot-border", source: geoJsonBorder });
    Utils.addFillLayer({ map, id: "lot-fill", source: geoJsonFill });

    this.draw();
  }

  onMapMoveEnd(data) {
    // this.draw();
  }
}

export default LotMap;
