import { DEF_LOT_SETTINGS as LOT } from "../../constants/lot";

export const lotDrawCoords = ({ coords, zoom = 16 }) => {
  const [p1, p2, p3, p4] = coordsAsArray(coords);

  if (zoom < 16) {
    const offsetX = (p2[1] - p1[1]) / 15;
    const offxetY = (p1[0] - p3[0]) / 15;

    const offsetXS = (p2[1] - p1[1]) * 0.66;
    const offxetYS = (p1[0] - p3[0]) * 0.66;

    return [
      [p1[1] + offsetXS, p1[0] - offxetYS],
      [p2[1] - offsetX, p2[0] - offxetYS],
      [p3[1] - offsetX, p3[0] + offxetY],
      [p4[1] + offsetXS, p4[0] + offxetY]
    ];
  } else {
    const offsetX = (p2[1] - p1[1]) / 15;
    const offxetY = (p1[0] - p3[0]) / 15;

    return [
      [p1[1] + offsetX, p1[0] - offxetY],
      [p2[1] - offsetX, p2[0] - offxetY],
      [p3[1] - offsetX, p3[0] + offxetY],
      [p4[1] + offsetX, p4[0] + offxetY]
    ];
  }
};

export const coordsAsArray = coords =>
  coords.map(v => {
    if (v instanceof Array) return v;
    return [v._latitude, v._longitude];
  });

export const featureConfig = (coords = []) => ({
  type: "Feature",
  properties: {},
  geometry: {
    type: "Polygon",
    coordinates: [coords]
  }
});

export const featureCollectionConfig = (features = []) => ({
  type: "FeatureCollection",
  features: features
});

export const addOutlineLayer = ({ map, id, source }) => {
  map.addLayer({
    id: id,
    type: "line",
    source: {
      type: "geojson",
      data: source
    },
    layout: {
      "line-join": "round",
      "line-cap": "round"
    },
    paint: {
      "line-color": LOT.STROKE.COLOR,
      "line-width": LOT.STROKE.WIDTH
    }
  });
};

export const addFillLayer = ({ map, id, source }) => {
  map.addLayer({
    id: id,
    type: "fill",
    source: {
      type: "geojson",
      data: source
    },
    paint: {
      "fill-color": LOT.FILL.COLOR,
      "fill-opacity": LOT.FILL.OPACITY
    }
  });
};
