import React from "react";
import { connect } from "react-redux";
import { Segment } from "semantic-ui-react";
import uuidv1 from "uuid/v1";

import StatusFilterButton from "./StatusFilterButton";

import { switchFilter } from "../../actions/lot";

import { FILTER } from "../../constants/lot";

import * as BIT from "../../utils/Bitwise";

import "./StatusFilters.scss";

class StatusFilters extends React.Component {
  render() {
    const { filter, switchFilter } = this.props;

    return (
      <Segment className="flat flex filters">
        <div className="flex-2 anothers" style={{ marginRight: 20 }}>
          <div className="flex flex-col">
            <h3>What are you looking for?</h3>
            <div className="flex">
              <StatusFilterButton
                key={uuidv1()}
                text="Lots of other users offered for rent"
                pressed={BIT.isset(filter, FILTER.FOR_RENT)}
                icon="rent"
                color="green"
                onClick={() => switchFilter(FILTER.FOR_RENT)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Lots of other users put up for auction"
                pressed={BIT.isset(filter, FILTER.AUCTION)}
                icon="auction"
                color="green"
                onClick={() => switchFilter(FILTER.AUCTION)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Lots of other users offered for sale"
                pressed={BIT.isset(filter, FILTER.FOR_SALE)}
                icon="user"
                color="green"
                onClick={() => switchFilter(FILTER.FOR_SALE)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Free selling lots"
                pressed={BIT.isset(filter, FILTER.FREE_SALE)}
                icon="sale"
                color="green"
                onClick={() => switchFilter(FILTER.FREE_SALE)}
              />
            </div>
          </div>
        </div>
        <div className="flex-3 own" style={{ marginLeft: 20 }}>
          <div className="flex flex-col">
            <h3>Your lots</h3>
            <div className="flex">
              <StatusFilterButton
                key={uuidv1()}
                text="Lots rented by you"
                pressed={BIT.isset(filter, FILTER.LEASED)}
                icon="rented"
                color="blue"
                onClick={() => switchFilter(FILTER.LEASED)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Lots offered for rent"
                pressed={BIT.isset(filter, FILTER.FOR_RENT + FILTER.OWN_SHIFT)}
                icon="rent"
                color="blue"
                onClick={() => switchFilter(FILTER.FOR_RENT, true)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Lots offered for sale"
                pressed={BIT.isset(filter, FILTER.FOR_SALE + FILTER.OWN_SHIFT)}
                icon="sale"
                color="blue"
                onClick={() => switchFilter(FILTER.FOR_SALE, true)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Lots offered for auction"
                pressed={BIT.isset(filter, FILTER.AUCTION + FILTER.OWN_SHIFT)}
                icon="auction"
                color="blue"
                onClick={() => switchFilter(FILTER.AUCTION, true)}
              />
              <StatusFilterButton
                key={uuidv1()}
                text="Your leased lots"
                pressed={BIT.isset(filter, FILTER.RENTED + FILTER.OWN_SHIFT)}
                icon="user"
                color="blue"
                onClick={() => switchFilter(FILTER.RENTED, true)}
              />
              {/* <StatusFilterButton key={uuidv1()} /> */}
            </div>
          </div>
        </div>
      </Segment>
    );
  }
}

const mapStateToProps = state => {
  const { filter } = state.lot;
  return { filter };
};
const mapDispatchToProps = dispatch => ({
  switchFilter: (bit, own = false) => dispatch(switchFilter({ bit, own }))
});

export default connect(
  mapStateToProps,
  mapDispatchToProps
)(StatusFilters);
