import React, { Component } from "react";
import { connect } from "react-redux";
import { compose } from "recompose";
import { withRouter } from "react-router-dom";

import * as ROUTES from "../../constants/routes";

import PaymentForm from "../../components/PaymentForm";
import UserDataBlock from "../../components/UserDataBlock";
import UserPaymentsList from "../../components/UserPaymentsList";

import { setActiveRoute } from "../../actions/page";

class AccountPage extends Component {
  constructor(props) {
    super(props);
    this.state = {
      showForm: true
    };
  }

  componentWillMount() {
    const { setActiveRoute } = this.props;
    setActiveRoute(ROUTES.ACCOUNT);
  }

  switchForm() {
    this.setState({ showForm: !this.state.showForm });
  }

  render() {
    const { authUser, history } = this.props;
    const { showForm } = this.state;

    if (!authUser) {
      history.push(ROUTES.SIGN_IN);
      return null;
    }

    return (
      <div className="page">
        <div className="flex">
          <div className="col flex-1">
            <UserDataBlock />
            {/* <Button primary onClick={this.switchForm.bind(this)}>
              {`${showForm ? "Hide payment form" : "Top up balance with card"}`}
            </Button> */}
          </div>
          <div className="col flex-1">
            {showForm && <PaymentForm userID={authUser.uid} />}
          </div>
        </div>
        <div className="flex">
          <div className="col flex-1">
            <UserPaymentsList />
          </div>
        </div>
      </div>
    );
  }
}

const mapStateToProps = state => {
  const { authUser } = state.session;
  return { authUser };
};

const mapDispatchToProps = dispatch => ({
  setActiveRoute: route => dispatch(setActiveRoute(route))
});

export default compose(
  withRouter,
  connect(
    mapStateToProps,
    mapDispatchToProps
  )
)(AccountPage);
