import React from "react";
import { connect } from "react-redux";
import { Segment, Button } from "semantic-ui-react";
import uuidv1 from "uuid/v1";

import StatusButton from "./StatusButton";
import OfferButton from "./OfferButton";
import RentButton from "./RentButton";

import { STATUS } from "../../../constants/lot";

const LotButtons = ({ lot, loading, user }) => {
  const { status, owner, price } = lot || {};

  const buttons = [];

  if (lot) {
    if (user.uid === lot.owner) {
      if (status === STATUS.NOT_FOR_SALE)
        buttons.push(
          <OfferButton
            key={uuidv1()}
            color="#ED4956"
            value={price}
            buttonText="Sell"
            status={STATUS.FOR_SALE}
            priceField="userPrice"
          />,
          <div key={uuidv1()} className="ui horizontal divider">Or</div>,
          <OfferButton
            key={uuidv1()}
            color="#262626"
            value={Math.max(price / 12, 1)}
            buttonText="Rent out"
            fieldLabel="per day"
            status={STATUS.FOR_RENT}
            priceField="rentPrice"
          />
        );
      else if (status === STATUS.RENTED)
        buttons.push(
          <Button key={uuidv1()} color="black">
            Rented by another user
          </Button>
        );
      else
        buttons.push(
          <StatusButton
            key={uuidv1()}
            color="black"
            content={`Cancel ${
              status === STATUS.FOR_RENT ? "rent" : "sale"
            } offer`}
            status={STATUS.NOT_FOR_SALE}
          />
        );
    } else {
      if (status === STATUS.FOR_SALE)
        buttons.push(
          <Button key={uuidv1()} color="black">
            Buy
          </Button>
        );
      else if (status === STATUS.FOR_RENT)
        buttons.push(<RentButton key={uuidv1()} color="black" />);
      else if (status === STATUS.RENTED)
        buttons.push(
          <Button key={uuidv1()} color="black">
            Rented
          </Button>
        );
      else if (owner)
        buttons.push(
          <Button key={uuidv1()} color="black">
            Sale request
          </Button>,
          <Button key={uuidv1()} color="black">
            Rent request
          </Button>
        );
    }
  }

  return (
    <Segment className="lot_actions flat flex" loading={loading}>
      {buttons}
    </Segment>
  );
};

const mapStateToProps = state => {
  const { authUser } = state.session;
  const { currentLot, lotStatusChanging, lotFetching } = state.lot;

  return {
    lot: currentLot,
    loading: lotFetching || lotStatusChanging,
    user: authUser
  };
};

export default connect(mapStateToProps)(LotButtons);
