import React from "react";
import { connect } from "react-redux";
import { compose } from "recompose";
import { withFirebase } from "../../../components/Firebase";
import { Button } from "semantic-ui-react";

import * as ACTIONS from "../../../actions/lot";

class StatusButton extends React.Component {
  onclick(e) {
    const {
      firebase,
      lot,
      status,
      setLotStatusStart,
      setLotStatusSuccess,
      setLotStatusError
    } = this.props;
    e.preventDefault();
    setLotStatusStart();
    firebase
      .setLotStatus({ lotid: lot.uid, status })
      .then(response => {
        try {
          const data = JSON.parse(response.data.lot)[lot.uid];
          setLotStatusSuccess({ ...data, uid: lot.uid });
        } catch (error) {
          setLotStatusError(error);
        }
      })
      .catch(error => {
        setLotStatusError(error);
      });
  }

  render() {
    const { color, content } = this.props;

    return (
      <Button color={color} onClick={this.onclick.bind(this)}>
        {content}
      </Button>
    );
  }
}

const mapStateToProps = state => {
  const { currentLot } = state.lot;

  return { lot: currentLot };
};
const mapDispatchToProps = dispatch => ({
  setLotStatusStart: () => dispatch(ACTIONS.setLotStatusStart()),
  setLotStatusSuccess: data => dispatch(ACTIONS.setLotStatusSuccess(data)),
  setLotStatusError: error => dispatch(ACTIONS.setLotStatusError(error))
});

export default compose(
  withFirebase,
  connect(
    mapStateToProps,
    mapDispatchToProps
  )
)(StatusButton);
