import React from "react";
import { Button, Label } from "semantic-ui-react";

class StatusInputButton extends React.Component {
  constructor(props) {
    super(props);
    const { value = 0 } = props;

    this.state = {
      value: Math.max(parseFloat(value) / 100, 0).toFixed(2)
    };
  }

  onclick(e) {
    const { action = () => void 0, actionParams = {} } = this.props;

    if (e.target.tagName === "INPUT") return false;
    e.preventDefault();
    const button = e.currentTarget;
    const input = button.querySelector("input");
    let value = input.value;
    if (value && !isNaN(value)) {
      action({ ...actionParams, value: parseInt(value * 100) });
    }
  }

  validate(e) {
    const value = (Math.max(parseFloat(e.target.value) * 100, 0) / 100).toFixed(
      2
    );
    this.setState({ value });
  }

  render() {
    const { color, text, label, min = 0, max } = this.props;
    const { value } = this.state;
    return (
      <Button as="div" labelPosition="right" onClick={this.onclick.bind(this)}>
        <Button color={color}>{text}</Button>
        <Label as="a" basic color={color} pointing="left">
          <div>
            <div className="ui left icon input" style={{ width: 120 }}>
              <input
                type="number"
                value={value}
                onChange={this.validate.bind(this)}
                min={min}
              />
              <i aria-hidden="true" className="dollar sign icon" />
            </div>
            {label && <span style={{ marginLeft: 10 }}>{label}</span>}
          </div>
        </Label>
      </Button>
    );
  }
}
// {
//   const StatusInputButton = ({
//   color,
//   value = 0,
//   text,
//   type = "text",
//   action = () => void 0,
//   label,
//   actionParams = {}
// }) => {
//   this.state = {
//     value: value
//   };
//   const onclick = e => {
//     if (e.target.tagName === "INPUT") return false;
//     e.preventDefault();
//     const button = e.currentTarget;
//     const input = button.querySelector("input");
//     let value = input.value;
//     if (value && !isNaN(value)) {
//       action({ ...actionParams, value: parseInt(value * 100) });
//     }
//   };
//   const validate = (e, input) => {
//     const value = Math.max(parseFloat(input.value) * 100, 0).toFixed(2);
//     console.log(value);

//     input.value = value;
//   };
//   return (
//     <Button as="div" labelPosition="right" onClick={onclick}>
//       <Button color={color}>{text}</Button>
//       <Label as="a" basic color={color} pointing="left">
//         <div>
//           <Input
//             icon="dollar sign"
//             iconPosition="left"
//             defaultValue={value}
//             type={type}
//             style={{ width: 120 }}
//             onChange={validate}
//           />
//           {label && <span style={{ marginLeft: 10 }}>{label}</span>}
//         </div>
//       </Label>
//     </Button>
//   );
// };

export default StatusInputButton;
